'''
simple script to verify data in the index file:

http://s3.amazonaws.com/aws-publicdatasets/trec/kba/kba-streamcorpus-2013-v0_2_0-chunk-path-to-stream-id-time.txt.xz

'''

import sys
import streamcorpus

def log(m):
    sys.stdout.write(m)
    sys.stdout.write('\n')
    sys.stdout.flush()

for line in sys.stdin:
    line = line.strip()
    if not line:
        continue
    parts = line.split(':')
    chunk_path = parts[0]

    actual_date_hour = chunk_path.split('/')[3]
    expected_num_stream_ids = int(chunk_path.split('/')[4].split('-')[1])

    recs = ':'.join(parts[1:])
    recs = recs.strip()
    num_wrong_epoch_ticks = 0
    num_wrong_zulu_timestamps = 0
    num_stream_ids = 0
    wrong_epoch_ticks = set()
    for rec in recs.split('|'):
        rec = rec[1:-1]
        try:
            stream_id, st_epoch, st_zulu = rec.split(',')
        except:
            #print repr(line)
            #sys.exit(repr(rec))
            continue

        num_stream_ids += 1

        epoch_ticks, doc_id = stream_id.split('-')
        assert epoch_ticks == st_epoch

        new_st = streamcorpus.make_stream_time(st_zulu)
        if not (new_st.epoch_ticks == float(st_epoch)):
            num_wrong_epoch_ticks += 1
            wrong_epoch_ticks.add( new_st.epoch_ticks - float(st_epoch) )

        correct_date_hour = st_zulu.split(':')[0].replace('T', '-')
        if not (actual_date_hour == correct_date_hour):
            num_wrong_zulu_timestamps += 1
            log("WRONG: %s" % line)

    if num_wrong_zulu_timestamps == 0:
        log('correct')

    if not (num_stream_ids == expected_num_stream_ids):
        #print 'WARN: incorrect num stream ids'
        pass #print line

    #print num_wrong_epoch_ticks, num_wrong_zulu_timestamps, num_wrong_epoch_ticks - num_stream_ids, num_wrong_zulu_timestamps - num_stream_ids, num_stream_ids, (expected_num_stream_ids - num_stream_ids), repr(wrong_epoch_ticks), line
    #print '%r - %r = %r for %s' % (new_st, st_epoch, new_st.epoch_ticks - float(st_epoch), line)
